"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const shared_utils_1 = require("@vuepress/shared-utils");
function handleOptions(options, ctx) {
    let { directories = [] } = options;
    directories = directories.filter(directory => {
        const targetDir = path_1.join(ctx.sourceDir, directory.dirname);
        if (fs_1.existsSync(targetDir)) {
            return true;
        }
        shared_utils_1.logger.warn(`[@fhtw/plugin-directory-classifier]` +
            `  Invalid directory classifier: ${shared_utils_1.chalk.cyan(directory.id)}, ` +
            `  ${shared_utils_1.chalk.gray(targetDir)} doesn't exist!`);
        return false;
    });
    const extraPages = [];
    const pageEnhancers = [];
    for (const directory of directories) {
        const { id, dirname, path: indexPath = `/${directory.id}/`, layout: indexLayout = "IndexPage", frontmatter, itemLayout = "Page", nav } = directory;
        if (!indexPath) {
            continue;
        }
        extraPages.push({
            permalink: indexPath,
            frontmatter: {
                layout: ctx.getLayout(indexLayout),
                title: capitalize(id),
                itemPath: dirname,
                ...frontmatter
            },
            meta: {
                id
            }
        });
        if (nav) {
            const { nav: navBar } = ctx.themeConfig;
            if (nav.order > 0 && nav.order < navBar.length) {
                navBar.splice(nav.order - 1, 0, {
                    text: nav.title,
                    link: indexPath
                });
            }
        }
        pageEnhancers.push({
            when: ({ regularPath }) => filterIndexedPages(regularPath, indexPath, dirname),
            frontmatter: {
                layout: ctx.getLayout(itemLayout, "Page")
            },
            data: {
                id
            }
        });
    }
    return {
        pageEnhancers,
        extraPages
    };
}
exports.handleOptions = handleOptions;
function capitalize(text) {
    return text.replace(/(?:^|\s)\S/g, l => l.toUpperCase());
}
function filterIndexedPages(regularPath, indexPath, dirname) {
    return (Boolean(regularPath) &&
        regularPath !== indexPath &&
        regularPath.startsWith(`/${dirname}/`) &&
        (regularPath.endsWith("index.html") ||
            regularPath.endsWith("/") ||
            isFirstLevelEntry(regularPath, indexPath)));
}
function isFirstLevelEntry(itemPath, indexPath) {
    const p = path_1.relative(indexPath, itemPath);
    return p.split("/").length == 1;
}
//# sourceMappingURL=handleOptions.js.map